@@ -4,6 +4,7 @@ This module contains the Atos class, which have all that is necessary to
 extract information from a specialized act.
 """
 
+import re
 import pandas as pd
 
 from dodfminer.extract.polished.backend.regex import ActRegex
@@ -11,7 +12,7 @@ from dodfminer.extract.polished.backend.ner import ActNER
 from dodfminer.extract.polished.backend.seg import ActSeg
 
 
-class Atos(ActRegex, ActNER, ActSeg):
+class Atos(ActRegex, ActNER, ActSeg):  # pylint: disable=too-many-instance-attributes
     """Base class for extracting an act and its proprieties to a dataframe.
 
     Note:
@@ -52,7 +53,7 @@ class Atos(ActRegex, ActNER, ActSeg):
             self._file_name = None
 
         self._acts_str = []
-        self._columns = self._props_names()
+        self._columns = self._props_names() + self._standard_props_names()
 
         self._raw_acts = self._seg_function()
         self._acts = self._extract_props()
@@ -98,6 +99,15 @@ class Atos(ActRegex, ActNER, ActSeg):
         """
         raise NotImplementedError
 
+    #pylint: disable=no-self-use
+    def _standard_props_names(self, capitalize=False):
+        props = ['DODF_Fonte_Arquivo', 'DODF_Fonte_Data', 'DODF_Fonte_Numero']
+
+        if capitalize:
+            props = [name.capitalize() for name in props]
+
+        return props
+
     def _build_dataframe(self):
         """Create a dataframe with the extracted proprieties.
 
@@ -108,18 +118,61 @@ class Atos(ActRegex, ActNER, ActSeg):
             data_frame = pd.DataFrame(self._acts)
             if self._backend == 'regex':
                 data_frame.columns = self._columns
+                self._check_cols(data_frame.columns)
             else:
                 data_frame.columns = [x.capitalize()
                                       for x in data_frame.columns]
             return data_frame
         return pd.DataFrame()
 
+    def _standard_props(self):
+        act = {}
+
+        file = self._file_name.split('/')[-1] if self._file_name else None
+        match = re.search(r'(\d+\-\d+\-\d+)',file) if file else None
+        file_split = file.split() if file else None
+
+        act['DODF_Fonte_Arquivo'] = file.replace('.txt', '.pdf') if file else None
+        act['DODF_Fonte_Data'] = match.group(1).replace('-', '/') if match else None
+        act['DODF_Fonte_Numero'] = file_split[1] if file_split and len(file_split)>=2 else None
+
+        return act
+
+    def get_expected_colunms(self) -> list:
+        '''
+        Get the expected columns for the dataframe
+        Raises:
+            NotImplementedError: Child class needs to overwrite this method.
+        '''
+        raise NotImplementedError
+
+    def _check_cols(self, columns: list) -> None:
+        '''
+            Check if dataframe columns are the expected ones
+            Raises:
+                NotImplementedError: Child class needs to overwrite this method.
+
+        '''
+        for col in self.get_expected_colunms():
+            if col not in columns:
+                raise KeyError(f'Key not present in dataframe -> {col}')
+
+    def add_standard_props(self, act, capitalize=False):
+        standard_props = self._standard_props()
+
+        if capitalize:
+            standard_props = {(key.capitalize()):val for key, val in standard_props.items()}
+
+        act = {**act, **(standard_props)}
+        return act
+
     def _extract_props(self):
         """Extract proprieties of all the acts.
 
         Returns:
             A vector of extracted acts dictionaries.
         """
+
         acts = []
         for value in self._raw_acts:
             act = {}
@@ -129,5 +182,7 @@ class Atos(ActRegex, ActNER, ActSeg):
                 act = self._prediction(value)
             else:
                 raise NotImplementedError("Non-existent backend option")
-            acts.append(act)
+            # Merge act props with standard props
+            acts.append(self.add_standard_props(act))
+
         return acts
