@@ -4,12 +4,10 @@ This module contains the ActRegex class, which have all that is necessary to
 extract an act and, its proprieties, using regex rules.
 
 """
-import abc
-
 import re
 import numpy as np
 
-
+#pylint: disable=too-few-public-methods
 class ActRegex:
     """Act Regex Class.
 
@@ -33,7 +31,7 @@ class ActRegex:
         # self._text = None
 
         #Act Regex Constuction
-        super(ActRegex, self).__init__()
+        super().__init__()
         self._flags = self._regex_flags()
         self._rules = self._prop_rules()
         self._inst_rule = self._rule_for_inst()
@@ -64,25 +62,11 @@ class ActRegex:
         """
         raise NotImplementedError
 
-    def _regex_flags(self):
+    @classmethod
+    def _regex_flags(cls):
         """Flag of the regex search"""
         return 0
 
-    def _regex_instances(self):
-        """Search for all instances of the act using the defined rule.
-
-        Returns:
-            List of all act instances in the text.
-        """
-        found = re.findall(self._inst_rule, self._text, flags=self._flags)
-        results = []
-        for instance in found:
-            head, body = instance
-            self._acts_str.append(head+body)
-            results.append(body)
-
-        return results
-
     def _find_prop_value(self, rule, act):
         """Find a single proprietie in an single act.
 
@@ -100,7 +84,7 @@ class ActRegex:
 
         return np.nan
 
-    def _regex_props(self, act_raw):
+    def _regex_props(self, act_raw) -> dict:
         """Create an act dict with all its proprieties.
 
         Args:
@@ -111,11 +95,12 @@ class ActRegex:
 
         """
         act = {}
+        # pylint: disable=no-member
         act["tipo_ato"] = self._name
         for key in self._rules:
             try:
                 act[key], = self._find_prop_value(self._rules[key], act_raw)
-            except Exception:
+            except (TypeError, ValueError):
                 act[key] = np.nan
 
         return act
