@@ -47,7 +47,7 @@ def load_blocks_list(path):
 
     """
     doc = fitz.open(path)
-    return [p.getTextPage().extractDICT()['blocks'] for p in doc]
+    return [p.get_textpage().extractDICT()['blocks'] for p in doc]
 
 
 def group_by_column(elements, width):
@@ -148,7 +148,7 @@ def _extract_bold_upper_page(page):
 
     """
     lis = []
-    for block in page.getTextPage().extractDICT()['blocks']:
+    for block in page.get_textpage().extractDICT()['blocks']:
         for line in block['lines']:
             for span in line['spans']:
                 flags = span['flags']
@@ -250,9 +250,9 @@ def _get_titles_subtitles(elements, width_lis):
                                current_element['bbox'],
                                current_element['page']])
             elements = elements[1:]
-        else:
-            break
-        previous_element = current_element
+            previous_element = current_element
+            continue
+        break
 
     # Titles with more than one line should be a single string
 
@@ -271,9 +271,9 @@ def _get_titles_subtitles(elements, width_lis):
                 sub_titles.append((current_element['text'], _TYPE_SUBTITLE,
                                    current_element['bbox'],
                                    current_element['page']))
-            else:   # this and next elements has others font sizes;
-                break
-            elements = elements[1:]
+                elements = elements[1:]
+                continue
+            break
         sub_titles = [TextTypeBboxPageTuple(*i) for i in sub_titles]
 
     # Sometimes heuristic fails. However, the fix below seems to work on most
@@ -282,8 +282,8 @@ def _get_titles_subtitles(elements, width_lis):
 
     if not titles and sub_titles:
         return TitlesSubtitles([invert_text_type_bbox_page_tuple(i) for i in sub_titles], titles)
-    else:
-        return TitlesSubtitles(titles, sub_titles)
+
+    return TitlesSubtitles(titles, sub_titles)
 
 
 def _get_titles_subtitles_smart(doc, width_lis):
@@ -340,7 +340,7 @@ def extract_titles_subtitles(path):
 # instance through appending elements to its internals lists)
 
 
-class ExtractorTitleSubtitle(object):
+class ExtractorTitleSubtitle:
     """Use this class like that:
     >> path = "path_to_pdf"
     >> extractor = ExtractorTitleSubtitle(path)
@@ -395,7 +395,8 @@ class ExtractorTitleSubtitle(object):
                     else:
                         break
             else:
-                raise ValueError("Does not begin with a title")
+                print("Does not begin with a title")
+                i += 1
         _json = {k: tuple(val) for k, val in _json.items()}
         self._json = _json
         return self._json
@@ -535,7 +536,7 @@ class ExtractorTitleSubtitle(object):
         """
         self._json = {}
         self._hierarchy = []
-        self._cache = False
+        self._cached = False
 
 
 def gen_title_base(dir_path=".", base_name="titles", indent=4, forced=False):
@@ -554,7 +555,8 @@ def gen_title_base(dir_path=".", base_name="titles", indent=4, forced=False):
     if os.path.exists(base_name) and not forced:
         print(f"Error: {base_name} already exists")
         return None
-    elif os.path.isdir(base_name):
+
+    if os.path.isdir(base_name):
         print(f"Error: {base_name} ir a directory")
         return None
 
@@ -601,7 +603,7 @@ def gen_hierarchy_base(dir_path=".",
         In case of error trying to create `base_name` folder,
         returns None.
     """
-    folder = "{}/{}".format(dir_path, folder)
+    folder = f"{dir_path}/{folder}"
     if not dir_path:
         dir_path = "."
     try:
@@ -612,8 +614,8 @@ def gen_hierarchy_base(dir_path=".",
 
     hierarchies = []
     for file in filter(lambda x: x.endswith('.pdf'), os.listdir(dir_path)):
-        et = ExtractorTitleSubtitle("{}/{}".format(dir_path, file))
-        hierarchy = et.titles_subtitles_hierarchy
+        extractor = ExtractorTitleSubtitle(f"{dir_path}/{file}")
+        hierarchy = extractor.titles_subtitles_hierarchy
         hierarchy = [
             ({d[0]: [dict([(i, '')]) for i in d[1]]})
             for d in hierarchy
@@ -621,9 +623,9 @@ def gen_hierarchy_base(dir_path=".",
         hierarchy = {file.rstrip('.pdf'): hierarchy}
         hierarchies.append(hierarchy)
 
-        json.dump(hierarchy,
-                  open("{}/{}.json".format(
-                      folder, file.rstrip('.pdf')), 'w'),
-                  ensure_ascii=False, indent=indent*' ')
+        with open(f"{folder}/{file.rstrip('.pdf')}.json", 'w', encoding='utf-8') as json_path:
+            json.dump(hierarchy,
+                      json_path,
+                      ensure_ascii=False, indent=indent*' ')
 
     return hierarchies
